==> verttice_ui-0.0.97.tar.gz: lib/src/widgets/themed_widgets/themed_editor/editor_universal_ui/web_youtube_player.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_quill/flutter_quill.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:youtube_player_flutter/youtube_player_flutter.dart' as yti;
import 'package:youtube_player_iframe/youtube_player_iframe.dart';

class WebYoutubeVideoApp extends StatefulWidget {
  final String videoUrl;
  final BuildContext context;
  final bool readOnly;

  const WebYoutubeVideoApp({
    Key? key,
    required this.videoUrl,
    required this.context,
    required this.readOnly,
  }) : super(key: key);

  @override
  _WebYoutubeVideoAppState createState() => _WebYoutubeVideoAppState();
}

class _WebYoutubeVideoAppState extends State<WebYoutubeVideoApp> {
  YoutubePlayerController? _controller;

  @override
  void initState() {
    super.initState();
    final videoId = yti.YoutubePlayer.convertUrlToId(widget.videoUrl);
    if (videoId != null) {
      _controller = YoutubePlayerController(
        initialVideoId: videoId,
        params: const YoutubePlayerParams(
          showControls: true,
          autoPlay: false,
          showFullscreenButton: true,
        ),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    final defaultStyles = DefaultStyles.getInstance(context);
    if (_controller == null) {
      if (widget.readOnly) {
        return RichText(
          text: TextSpan(
            text: widget.videoUrl,
            style: defaultStyles.link,
            recognizer: TapGestureRecognizer()
              ..onTap = () => launchUrl(
                    Uri.parse(
                      widget.videoUrl,
                    ),
                  ),
          ),
        );
      }

      return RichText(
        text: TextSpan(
          text: widget.videoUrl,
          style: defaultStyles.link,
        ),
      );
    }

    return SizedBox(
      height: 300,
      child: YoutubePlayerControllerProvider(
        controller: _controller!,
        child: const YoutubePlayerIFrame(
          aspectRatio: 16 / 9,
        ),
      ),
    );
  }
}

==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/themed_widgets/themed_editor/editor_universal_ui/web_youtube_player.dart <==
// 🐦 Flutter imports:
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:flutter_quill/flutter_quill.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:youtube_player_iframe/youtube_player_iframe.dart';

String? convertUrlToId(String url, {bool trimWhitespaces = true}) {
  if (!url.contains("http") && (url.length == 11)) return url;
  if (trimWhitespaces) url = url.trim();

  for (var exp in [
    RegExp(
        r"^https:\/\/(?:www\.|m\.)?youtube\.com\/watch\?v=([_\-a-zA-Z0-9]{11}).*$"),
    RegExp(
        r"^https:\/\/(?:www\.|m\.)?youtube(?:-nocookie)?\.com\/embed\/([_\-a-zA-Z0-9]{11}).*$"),
    RegExp(r"^https:\/\/youtu\.be\/([_\-a-zA-Z0-9]{11}).*$")
  ]) {
    Match? match = exp.firstMatch(url);
    if (match != null && match.groupCount >= 1) return match.group(1);
  }

  return null;
}

class WebYoutubeVideoApp extends StatefulWidget {
  final String videoUrl;
  final BuildContext context;
  final bool readOnly;

  const WebYoutubeVideoApp({
    Key? key,
    required this.videoUrl,
    required this.context,
    required this.readOnly,
  }) : super(key: key);

  @override
  State<WebYoutubeVideoApp> createState() => _WebYoutubeVideoAppState();
}

class _WebYoutubeVideoAppState extends State<WebYoutubeVideoApp> {
  YoutubePlayerController? _controller;

  @override
  void initState() {
    super.initState();
    final videoId = convertUrlToId(widget.videoUrl);
    if (videoId != null) {
      _controller = YoutubePlayerController(
        initialVideoId: videoId,
        params: const YoutubePlayerParams(
          showControls: true,
          autoPlay: false,
          showFullscreenButton: true,
        ),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    final defaultStyles = DefaultStyles.getInstance(context);
    if (_controller == null) {
      if (widget.readOnly) {
        return RichText(
          text: TextSpan(
            text: widget.videoUrl,
            style: defaultStyles.link,
            recognizer: TapGestureRecognizer()
              ..onTap = () => launchUrl(
                    Uri.parse(
                      widget.videoUrl,
                    ),
                  ),
          ),
        );
      }

      return RichText(
        text: TextSpan(
          text: widget.videoUrl,
          style: defaultStyles.link,
        ),
      );
    }

    return SizedBox(
      height: 300,
      child: YoutubePlayerControllerProvider(
        controller: _controller!,
        child: const YoutubePlayerIFrame(
          aspectRatio: 16 / 9,
        ),
      ),
    );
  }
}
